#!/usr/bin/env python3
# -*- coding: utf-8 -*-
'''
Criticality: High
Checks that MediaWorker can be reached using SSH and that it can reach the tasks server
'''
from pathlib import Path
import requests
import sys

try:
    from requests.packages.urllib3.exceptions import InsecureRequestWarning

    requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
except ImportError:
    requests.packages.urllib3.disable_warnings()

sys.path.append(str(Path(__file__).parents[1].resolve()))

# pylint: disable=wrong-import-position
from utilities import logging as lg  # noqa: E402


def check_workers():
    '''
    Check remote workers using the Celerity API.
    '''
    try:
        import mediaserver
    except ImportError:
        lg.log('MediaServer is not installed, skipping test.')
        return 2
    else:
        lg.log('MediaServer version: %s.' % mediaserver.__version__)

    healthy_list = list()
    offline_list = list()
    need_update_list = list()
    try:
        from celerity_utils import api
        success, response = api.list_workers('celerity_config_updater')
        if not success:
            raise Exception(str(response))
        for worker in response['workers']:
            if not worker.get('online'):
                offline_list.append(worker['name'])
            elif not worker.get('up_to_date'):
                need_update_list.append(worker['name'])
            else:
                healthy_list.append(worker['name'])
    except Exception as e:
        lg.error('Failed to get workers list using celerity API: %s' % e)
        return 1
    if need_update_list:
        lg.error('The celerity version in following MediaWorkers is not the same as in MediaServer:\n  %s' % ', '.join(need_update_list))
        return 1
    if offline_list:
        lg.warning('Some MediaWorkers are offline:\n  %s' % ', '.join(offline_list))
    if not healthy_list:
        lg.error('No MediaWorker is online and up to date.')
        return 1
    lg.success('The following MediaWorkers are online and up to date:\n  %s' % ', '.join(healthy_list))
    return 0


if __name__ == '__main__':
    code = check_workers()
    sys.exit(code)
